<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title=" Schematron file for OUL_R22 - Verzenden resultaat uitbesteding "
                              schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="hl7"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="cda"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v2xml" prefix="hl7v2"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M7"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000</xsl:attribute>
            <xsl:attribute name="name">Lab2Lab Resultaatbericht (OUL^R22)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">template-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000-closed</xsl:attribute>
            <xsl:attribute name="name">Lab2Lab Resultaatbericht (OUL^R22)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl"> Schematron file for OUL_R22 - Verzenden resultaat uitbesteding </svrl:text>

   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000Lab2Lab Resultaatbericht (OUL^R22)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab2Lab Resultaatbericht (OUL^R22)</svrl:text>

	  <!--RULE d19e7127-false-d524682e0-->
   <xsl:template match="/hl7v2:OUL_R22" priority="10150" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:MSH is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:MSH komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:NTE komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.PATIENT)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.PATIENT)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.PATIENT is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.PATIENT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.PATIENT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.PATIENT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.VISIT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.VISIT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.VISIT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.SPECIMEN)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.SPECIMEN)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.SPECIMEN is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DSC)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:DSC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH" priority="10149" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.4)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.7 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.9 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.10 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.12 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.15)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.15 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.16)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.16 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.21)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.21 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSH.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.1"
                 priority="10148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Field Separator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Field Separator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.2"
                 priority="10147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('2') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('2') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Encoding Characters') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Encoding Characters' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3"
                 priority="10146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('3') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('3') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '3' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70361' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sending Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Sending Application' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="10144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="10143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="10142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4"
                 priority="10140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('4') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('4') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '4' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70362' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sending Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Sending Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="10138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="10137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="10136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5"
                 priority="10134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('5') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('5') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '5' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70361') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70361' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Receiving Application') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Receiving Application' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="10132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="10131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="10130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6"
                 priority="10128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('6') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('6') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '6' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70362') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70362' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Receiving Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Receiving Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="10126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="10125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="10124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7"
                 priority="10122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('7') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('7') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '7' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time Of Message' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="10120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="10119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.8"
                 priority="10117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('8') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('8') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '8' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Security') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Security' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9"
                 priority="10116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OUL^R22^OUL_R22'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='OUL^R22^OUL_R22'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de element content van hl7v2:MSH.9 MOET ''OUL^R22^OUL_R22'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MSG.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OUL^R22^OUL_R22'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='OUL^R22^OUL_R22'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.9 MOET ''OUL^R22^OUL_R22'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('9') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('9') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '9' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('MSG') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'MSG' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Message Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Message Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="10114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70076') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @Table MOET 'HL70076' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Message Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @LongName MOET 'Message Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="10112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70003') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @Table MOET 'HL70003' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Trigger Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @LongName MOET 'Trigger Event' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="10110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70354') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @Table MOET 'HL70354' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Message Structure') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSG_datatype): de waarde van @LongName MOET 'Message Structure' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.10"
                 priority="10108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('10') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('10') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '10' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Message Control ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Message Control ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11"
                 priority="10107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PT.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('11') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('11') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '11' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'PT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Processing ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="10105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70103') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van @Table MOET 'HL70103' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Processing ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van @LongName MOET 'Processing ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="10103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70207') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van @Table MOET 'HL70207' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Processing Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PT_datatype): de waarde van @LongName MOET 'Processing Mode' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12"
                 priority="10101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='2.5'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de element content van hl7v2:MSH.12 MOET ''2.5'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:VID.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='2.5'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.12 MOET ''2.5'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('12') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('12') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '12' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('VID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('VID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'VID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="10099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70104') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @Table MOET 'HL70104' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @LongName MOET 'Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="10097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @Table MOET 'HL70399' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Internationalization Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @LongName MOET 'Internationalization Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="10095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="10094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="10093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="10091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="10090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="10089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="10087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('International Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(VID_datatype): de waarde van @LongName MOET 'International Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="10085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="10084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="10083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="10081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="10080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="10079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.13"
                 priority="10077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('13') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('13') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '13' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Sequence Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.14"
                 priority="10076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('14') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('14') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '14' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Continuation Pointer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Continuation Pointer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.15"
                 priority="10075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('15') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('15') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '15' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70155' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Accept Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Accept Acknowledgment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.16"
                 priority="10073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:MSH.16 MOET ''NE'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.16 MOET ''NE'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('16') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('16') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '16' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70155') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70155' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Application Acknowledgment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Application Acknowledgment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.17"
                 priority="10071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NLD'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:MSH.17 MOET ''NLD'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NLD'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.17 MOET ''NLD'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('17') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('17') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '17' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70399' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Country Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.18"
                 priority="10069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('692') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('692') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '692' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70211') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70211' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Character Set') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Character Set' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19"
                 priority="10067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('693') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('693') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '693' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Principal Language Of Message') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Principal Language Of Message' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="10065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="10064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="10063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="10061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="10060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="10059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.20"
                 priority="10057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1317') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1317') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1317' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70356') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70356' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Character Set Handling Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Alternate Character Set Handling Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21"
                 priority="10055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1598') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1598') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1598' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Message Profile Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Message Profile Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="10053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="10052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="10051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="10050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT" priority="10048" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.4)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SFT.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): element hl7v2:SFT.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1"
                 priority="10047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1834') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1834') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Item MOET '1834' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Type MOET 'XON' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Vendor Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Software Vendor Organization') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @LongName MOET 'Software Vendor Organization' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.1"
                 priority="10045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.2"
                 priority="10044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.3"
                 priority="10043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.4"
                 priority="10042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.5"
                 priority="10041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6"
                 priority="10039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.1"
                 priority="10037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.2"
                 priority="10036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.3"
                 priority="10035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.7"
                 priority="10033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8"
                 priority="10031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.1"
                 priority="10029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.2"
                 priority="10028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.3"
                 priority="10027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.9"
                 priority="10025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.10"
                 priority="10023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.2"
                 priority="10022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1835') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1835') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Item MOET '1835' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Certified Version or Release Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Software Certified Version or Release Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @LongName MOET 'Software Certified Version or Release Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.3"
                 priority="10021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1836') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1836') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Item MOET '1836' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Product Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Software Product Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @LongName MOET 'Software Product Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.4"
                 priority="10020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1837') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1837') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Item MOET '1837' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Binary ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Software Binary ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @LongName MOET 'Software Binary ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.5"
                 priority="10019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1838') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1838') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Item MOET '1838' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Product Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Software Product Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @LongName MOET 'Software Product Information' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape"
                 priority="10018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape"
                 priority="10017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="10016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.6"
                 priority="10015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1839') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1839') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Item MOET '1839' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Install Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Software Install Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SFT_segment): de waarde van @LongName MOET 'Software Install Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.1"
                 priority="10013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.2"
                 priority="10012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE" priority="10010" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.1"
                 priority="10009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '96' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.2"
                 priority="10008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '97' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3"
                 priority="10006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '98' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'FT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="10005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="10004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="10003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4"
                 priority="10002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '1318' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="10000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="9999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="9998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="9996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="9995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="9994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7150-false-d528575e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT"
                 priority="9992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:PID is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:PID komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:PD1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID"
                 priority="9991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.24)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.25)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.27)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.28)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.30)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.31)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.33)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.34)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.35)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.36)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.37)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38)&lt;=2"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PID.38)&lt;=2">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): element hl7v2:PID.38 komt te vaak voor [max 2x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.1"
                 priority="9990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('104') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('104') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '104' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - PID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Set ID - PID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2"
                 priority="9989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('105') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('105') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '105' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="9987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="9986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="9985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="9983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="9977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="9975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="9969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="9968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="9967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="9954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3"
                 priority="9941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('106') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('106') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '106' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Identifier List') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Identifier List' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="9939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="9938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="9937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="9935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="9929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="9927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="9921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="9920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="9919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="9906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4"
                 priority="9893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('107') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('107') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '107' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Patient ID - PID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Alternate Patient ID - PID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="9891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="9890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="9889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="9887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="9881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="9879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="9873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="9872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="9871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="9858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5"
                 priority="9845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('108') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('108') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '108' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="9843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="9841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="9840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="9839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="9838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="9837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="9836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="9835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="9834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="9833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="9832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="9831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="9829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="9827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="9825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="9824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="9823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="9821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="9820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="9819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="9817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="9815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="9810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="9805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="9803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="9801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="9800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="9798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="9796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="9795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="9793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6"
                 priority="9792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('109') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '109' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="9790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="9788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="9787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="9786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="9785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="9784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="9783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="9782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="9781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="9780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="9779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="9778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="9776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="9774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="9772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="9771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="9770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="9768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="9767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="9766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="9764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="9762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="9757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="9752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="9750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="9748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="9747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="9745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="9743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="9742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="9740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7"
                 priority="9739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('110') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('110') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '110' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of Birth') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Date/Time of Birth' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="9737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="9736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.8"
                 priority="9734"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('111') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('111') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '111' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70001') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70001' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Administrative Sex') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Administrative Sex' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9"
                 priority="9732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XPN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('112') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('112') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '112' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XPN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Alias') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Alias' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="9730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="9728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="9727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="9726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="9725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="9724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="9723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="9722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="9721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="9720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="9719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="9718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="9716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="9714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="9712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="9711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="9710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="9708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="9707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="9706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="9704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="9702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="9697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="9692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="9690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="9688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="9687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="9685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="9683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="9682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="9680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10"
                 priority="9679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('113') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('113') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '113' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70005') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70005' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Race') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Race' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="9677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="9676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="9675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="9673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="9672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="9671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11"
                 priority="9669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('114') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('114') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '114' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XAD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="9667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="9665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="9664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="9663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="9662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="9661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="9660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="9659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="9658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="9656"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="9654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="9653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="9652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="9651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="9649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="9647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="9642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="9637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="9635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="9634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="9632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="9630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="9629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.12"
                 priority="9627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('115') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('115') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '115' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70289' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('County Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'County Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13"
                 priority="9626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('116') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('116') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '116' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XTN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Phone Number - Home') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Phone Number - Home' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="9624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="9623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="9621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="9619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="9618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="9617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="9616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="9615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="9614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="9613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="9612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="9611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14"
                 priority="9610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('117') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('117') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '117' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XTN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Phone Number - Business') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Phone Number - Business' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="9608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="9607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="9605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="9603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="9602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="9601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="9600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="9599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="9598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="9597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="9596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="9595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15"
                 priority="9594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('118') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '118' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70296') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70296' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Primary Language') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Primary Language' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="9592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="9591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="9590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="9588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="9587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="9586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16"
                 priority="9584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('119') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('119') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '119' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70002') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70002' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Marital Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Marital Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="9582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="9581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="9580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="9578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="9577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="9576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17"
                 priority="9574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('120') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '120' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70006') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70006' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Religion') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Religion' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="9572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="9571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="9570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="9568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="9567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="9566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18"
                 priority="9564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('121') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('121') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '121' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Account Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Account Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="9562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="9561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="9560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="9558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="9552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="9550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="9544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="9543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="9542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="9529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.19"
                 priority="9516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('122') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('122') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '122' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('SSN Number - Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'SSN Number - Patient' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20"
                 priority="9515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('123') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('123') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '123' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DLN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'DLN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Driver''s License Number - Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Driver''s License Number - Patient' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="9513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('License Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @LongName MOET 'License Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="9512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70333') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @Table MOET 'HL70333' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Issuing State, Province, Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @LongName MOET 'Issuing State, Province, Country' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="9511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21"
                 priority="9510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('124') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('124') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '124' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Mother''s Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Mother''s Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="9508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="9507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="9506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="9504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="9498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="9496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="9490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="9489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="9488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="9475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22"
                 priority="9462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('125') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70189') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70189' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ethnic Group') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Ethnic Group' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="9460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="9459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="9458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="9456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="9455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="9454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.23"
                 priority="9452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('126') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('126') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '126' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Birth Place') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Birth Place' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.24"
                 priority="9451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('127') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('127') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '127' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Multiple Birth Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Multiple Birth Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.25"
                 priority="9449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('128') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('128') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '128' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Birth Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Birth Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26"
                 priority="9448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('129') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '129' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70171') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70171' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Citizenship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Citizenship' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="9446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="9445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="9444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="9442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="9441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="9440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27"
                 priority="9438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('130') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('130') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '130' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70172') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70172' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Veterans Military Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Veterans Military Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="9436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="9435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="9434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="9432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="9431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="9430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28"
                 priority="9428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('739') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '739' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70212') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70212' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nationality') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Nationality' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="9426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="9425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="9424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="9422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="9421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="9420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29"
                 priority="9418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('740') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('740') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '740' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Death Date and Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Death Date and Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="9416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="9415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.30"
                 priority="9413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('741') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('741') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '741' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Death Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Death Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.31"
                 priority="9411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1535') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1535') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1535' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identity Unknown Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Identity Unknown Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.32"
                 priority="9409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1536') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1536') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1536' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70445') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70445' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identity Reliability Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Identity Reliability Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33"
                 priority="9408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1537') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1537') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1537' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Last Update Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Last Update Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="9406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="9405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34"
                 priority="9403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1538') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1538') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1538' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Last Update Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Last Update Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="9401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="9400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="9399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35"
                 priority="9397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1539') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1539') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1539' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70446') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70446' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Species Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Species Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="9395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="9394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="9393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="9391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="9390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="9389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36"
                 priority="9387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1540') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1540') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1540' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70447') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70447' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Breed Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Breed Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="9385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="9384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="9383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="9381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="9380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="9379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.37"
                 priority="9377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1541') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1541') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1541' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Strain') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Strain' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38"
                 priority="9376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1542') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1542') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1542' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70429') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70429' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Production Class Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Production Class Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="9374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="9373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="9372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="9370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="9369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="9368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39"
                 priority="9366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1840') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1840') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Item MOET '1840' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70171') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70171' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Tribal Citizenship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Tribal Citizenship' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="9364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="9363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="9362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="9360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="9359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="9358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="9356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="9355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="9354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1"
                 priority="9353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PD1.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.1"
                 priority="9352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('755') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '755' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70223') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70223' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Living Dependency') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Living Dependency' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.2"
                 priority="9351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('742') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '742' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70220') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70220' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Living Arrangement') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Living Arrangement' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3"
                 priority="9350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('756') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('756') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '756' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'XON' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Primary Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="9348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="9347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="9346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="9345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="9344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="9342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="9340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="9339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="9338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="9336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="9334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="9332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="9331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="9330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="9328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="9326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4"
                 priority="9325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('757') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('757') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '757' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="9323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="9322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="9315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="9314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="9313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="9312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="9311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="9310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="9309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="9303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="9301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="9300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="9298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="9296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="9290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="9288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="9278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="9266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="9264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="9259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="9254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="9253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="9240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.5"
                 priority="9227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('745') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '745' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70231') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70231' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Student Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Student Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.6"
                 priority="9226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('753') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '753' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70295') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70295' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Handicap') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Handicap' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.7"
                 priority="9225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '759' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70315') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70315' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Living Will Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Living Will Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.8"
                 priority="9224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '760' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70316') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70316' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organ Donor Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.9"
                 priority="9223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('761') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('761') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '761' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separate Bill') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Separate Bill' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10"
                 priority="9221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('762') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('762') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '762' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Duplicate Patient') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Duplicate Patient' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="9219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="9218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="9217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="9215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="9209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="9207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="9201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="9200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="9199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="9186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11"
                 priority="9173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('743') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '743' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70215') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70215' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Publicity Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Publicity Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="9171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="9170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="9169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="9167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="9166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="9165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.12"
                 priority="9163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('744') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '744' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Protection Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.13"
                 priority="9161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1566') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1566') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1566' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Protection Indicator Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14"
                 priority="9160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1567') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1567') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1567' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'XON' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Place of Worship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Place of Worship' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="9158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="9157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="9156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="9155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="9154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="9152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="9150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="9149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="9148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="9146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="9144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="9142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="9141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="9140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="9138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="9136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15"
                 priority="9135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1568') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1568') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1568' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70435') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70435' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Advance Directive Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="9133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="9132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="9131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="9129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="9128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="9127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.16"
                 priority="9125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70441') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70441' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Immunization Registry Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.17"
                 priority="9124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.18"
                 priority="9123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Publicity Code Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Publicity Code Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.19"
                 priority="9122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70140') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70140' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Military Branch') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Military Branch' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.20"
                 priority="9121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('486') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('486') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '486' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70141') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70141' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Military Rank/Grade') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Military Rank/Grade' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.21"
                 priority="9120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Item MOET '1573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70142') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @Table MOET 'HL70142' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Military Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PD1_segment): de waarde van @LongName MOET 'Military Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE"
                 priority="9119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="9118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '96' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="9117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '97' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="9115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '98' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'FT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="9114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="9113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="9112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="9111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '1318' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="9109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="9108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="9107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="9105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="9104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="9103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7159-false-d550268e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT"
                 priority="9101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:PV1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:PV1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:PV2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1"
                 priority="9100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.10)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.10 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.28)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.30)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.31)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.32)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.33)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.34)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.35)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.36)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.37)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.38)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.39)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.39 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.39)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.39 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.40)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.41)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.41 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.42)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.43)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.43 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.44)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.46)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.46 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.47)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.47 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.48)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.49)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.49 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.50)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.50 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV1.51)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): element hl7v2:PV1.51 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.1"
                 priority="9099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('131') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('131') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '131' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - PV1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Set ID - PV1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.2"
                 priority="9098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('132') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('132') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '132' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70004') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70004' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Class') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Class' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3"
                 priority="9097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('133') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('133') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '133' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigned Patient Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Assigned Patient Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="9095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="9094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="9093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="9092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="9090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="9089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="9088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="9086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="9085"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="9083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="9082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="9081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="9080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="9078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="9077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="9076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="9075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="9073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype_RIVM): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="9071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="9070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="9069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.4"
                 priority="9067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('134') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('134') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '134' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70007') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70007' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Admission Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admission Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5"
                 priority="9066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('135') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('135') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '135' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Preadmit Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Preadmit Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="9064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="9063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="9062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="9060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="9058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="9057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="9056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="9054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="9052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="9050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="9049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="9048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="9046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="9045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="9044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="9042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="9041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="9040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="9038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="9037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="9036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="9034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="9033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="9032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="9031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="9029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="9028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="9027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="9025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="9024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="9023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="9021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="9020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="9019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6"
                 priority="9018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('136') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('136') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prior Patient Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Prior Patient Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="9016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="9015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="9014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="9013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="9011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="9010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="9009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="9007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="9006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="9005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="9004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="9003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="9002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="9000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="8999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="8998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="8997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="8995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="8993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="8992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="8991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7"
                 priority="8989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('137') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('137') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '137' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Attending Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Attending Doctor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="8987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="8986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="8979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="8978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="8977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="8976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="8975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="8974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="8973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="8967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="8965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="8964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="8962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="8960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="8954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="8952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="8942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="8930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="8928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="8923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="8918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="8917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="8904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8"
                 priority="8891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('138') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('138') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '138' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Referring Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Referring Doctor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="8889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="8888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="8881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="8880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="8879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="8878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="8877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="8876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="8875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="8869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="8867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="8866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="8864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="8862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="8856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="8854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="8844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="8832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="8830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="8825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="8820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="8819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="8806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9"
                 priority="8793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('139') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('139') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '139' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Consulting Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Consulting Doctor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="8791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="8790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="8783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="8782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="8781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="8780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="8779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="8778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="8777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="8771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="8769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="8768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="8766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="8764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="8758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="8756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="8746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="8734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="8732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="8727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="8722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="8721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="8708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.10"
                 priority="8695"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('140') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('140') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '140' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70069') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70069' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Hospital Service') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Hospital Service' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11"
                 priority="8693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('141') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('141') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '141' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Temporary Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Temporary Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="8691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="8690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="8689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="8688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="8686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="8685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="8684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="8682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="8681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="8680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="8679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="8678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="8677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="8675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="8674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="8673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="8672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="8670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="8668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="8667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="8666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.12"
                 priority="8664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('142') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('142') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '142' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70087') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70087' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Preadmit Test Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Preadmit Test Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.13"
                 priority="8663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('143') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('143') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '143' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70092') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70092' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Re-admission Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Re-admission Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.14"
                 priority="8662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('144') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('144') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '144' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70023') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70023' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Admit Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admit Source' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.15"
                 priority="8661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('145') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '145' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70009') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70009' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ambulatory Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Ambulatory Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.16"
                 priority="8660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('146') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('146') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '146' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70099') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70099' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('VIP Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'VIP Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17"
                 priority="8659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('147') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('147') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '147' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Admitting Doctor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admitting Doctor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="8657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="8656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="8649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="8648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="8647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="8646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="8645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="8644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="8643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="8637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="8635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="8634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="8632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="8630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="8624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="8622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="8612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="8600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="8598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="8593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="8588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="8587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="8574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.18"
                 priority="8561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('148') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('148') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '148' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70018') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70018' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19"
                 priority="8560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('149') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('149') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '149' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Visit Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="8558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="8557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="8556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="8554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="8552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="8551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="8550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="8548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="8546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="8544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="8543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="8542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="8540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="8539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="8538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="8536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="8535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="8534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="8532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="8531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="8530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="8528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="8527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="8526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="8525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="8523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="8522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="8521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="8519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="8518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="8517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="8515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="8514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="8513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20"
                 priority="8512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FC.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FC.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('150') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('150') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '150' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FC') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FC') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'FC' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70064') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70064' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Financial Class') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Financial Class' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="8510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70064') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van @Table MOET 'HL70064' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Financial Class Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van @LongName MOET 'Financial Class Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="8509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FC_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="8507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="8506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.21"
                 priority="8504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('151') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('151') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '151' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70032') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70032' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Charge Price Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Charge Price Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.22"
                 priority="8503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('152') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('152') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '152' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70045') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70045' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Courtesy Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Courtesy Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.23"
                 priority="8502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('153') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('153') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '153' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70046') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70046' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Credit Rating') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Credit Rating' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.24"
                 priority="8501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('154') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('154') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '154' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70044') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70044' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Contract Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.25"
                 priority="8500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('155') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('155') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '155' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Contract Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.26"
                 priority="8499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('156') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('156') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '156' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Contract Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Amount' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.27"
                 priority="8498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('157') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('157') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '157' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Contract Period') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Period' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.28"
                 priority="8497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('158') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('158') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '158' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70073') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70073' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Interest Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Interest Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.29"
                 priority="8496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('159') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('159') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '159' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70110') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70110' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Transfer to Bad Debt Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.30"
                 priority="8495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('160') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('160') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '160' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Transfer to Bad Debt Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.31"
                 priority="8494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('161') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('161') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '161' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70021') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70021' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bad Debt Agency Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bad Debt Agency Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.32"
                 priority="8493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('162') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('162') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '162' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bad Debt Transfer Amount' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.33"
                 priority="8492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('163') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('163') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '163' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bad Debt Recovery Amount' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.34"
                 priority="8491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('164') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('164') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '164' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70111') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70111' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Delete Account Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Delete Account Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.35"
                 priority="8490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('165') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('165') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '165' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Delete Account Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Delete Account Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.36"
                 priority="8489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('166') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('166') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '166' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70112') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70112' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Discharge Disposition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Discharge Disposition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37"
                 priority="8488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DLD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('167') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('167') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '167' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DLD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DLD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70113') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70113' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Discharged to Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Discharged to Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="8486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70113') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van @Table MOET 'HL70113' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Discharge Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van @LongName MOET 'Discharge Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="8485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DLD_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="8483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="8482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38"
                 priority="8480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('168') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('168') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '168' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70114') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70114' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Diet Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Diet Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="8478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="8477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="8476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="8474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="8473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="8472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.39"
                 priority="8470"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('169') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('169') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '169' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70115') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70115' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Servicing Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Servicing Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.40"
                 priority="8468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('170') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('170') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '170' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70116') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70116' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bed Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.41"
                 priority="8467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('171') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('171') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '171' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70117') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70117' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Account Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Account Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42"
                 priority="8466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('172') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('172') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '172' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Pending Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Pending Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="8464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="8463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="8462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="8461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="8459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="8458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="8457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="8455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="8454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="8453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="8452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="8451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="8450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="8448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="8447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="8446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="8445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="8443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="8441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="8440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="8439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43"
                 priority="8437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('173') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('173') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '173' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prior Temporary Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Prior Temporary Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="8435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="8434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="8433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="8432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="8430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="8429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="8428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="8426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="8425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="8424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="8423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="8422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="8421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="8419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="8418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="8417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="8416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="8414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="8412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="8411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="8410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44"
                 priority="8408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('174') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('174') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '174' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Admit Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admit Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="8406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="8405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45"
                 priority="8403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('175') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('175') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '175' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Discharge Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Discharge Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="8401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="8400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.46"
                 priority="8398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('176') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('176') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '176' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Current Patient Balance') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Current Patient Balance' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.47"
                 priority="8397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('177') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('177') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '177' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total Charges') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Total Charges' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.48"
                 priority="8396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('178') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('178') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '178' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total Adjustments') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Total Adjustments' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.49"
                 priority="8395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('179') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('179') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '179' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total Payments') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Total Payments' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50"
                 priority="8394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CX.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('180') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('180') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '180' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Visit ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Alternate Visit ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="8392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="8391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="8390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="8388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="8386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="8385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="8384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="8382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="8380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="8378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="8377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="8376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="8374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="8373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="8372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="8370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="8369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="8368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="8366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="8365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="8364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="8362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="8361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="8360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="8359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="8357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="8356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="8355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="8353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="8352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="8351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="8349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="8348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="8347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.51"
                 priority="8346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '1226' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70326') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70326' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Visit Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52"
                 priority="8345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1274') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1274') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Item MOET '1274' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70010') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Healthcare Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Other Healthcare Provider' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="8343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="8342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="8335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="8334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="8333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="8332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="8331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="8330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="8329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="8323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="8321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="8320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="8318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="8316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="8310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="8308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="8298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="8286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="8284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="8279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="8274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="8273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="8260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2"
                 priority="8247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.24)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.25)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.26)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.27)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.28)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.30)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.31)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.32)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.33)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.34)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.35)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.36)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.37)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.38)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.40)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.42)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.43)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.44)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.46)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.47)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PV2.48)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1"
                 priority="8246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('181') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('181') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '181' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prior Pending Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Prior Pending Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="8244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="8243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="8242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="8241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="8239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="8238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="8237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="8235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="8234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="8233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="8232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="8231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="8230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="8228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="8227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="8226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="8225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="8223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="8221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="8220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="8219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2"
                 priority="8217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('182') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('182') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '182' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70129') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70129' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Accommodation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Accommodation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="8215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="8214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="8213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="8211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="8210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="8209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3"
                 priority="8207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('183') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('183') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '183' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Admit Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Admit Reason' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="8205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="8204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="8203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="8201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="8200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="8199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4"
                 priority="8197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('184') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('184') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '184' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transfer Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Transfer Reason' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="8195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="8194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="8193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="8191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="8190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="8189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.5"
                 priority="8187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('185') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('185') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '185' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Valuables') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.6"
                 priority="8186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('186') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('186') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '186' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Valuables Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.7"
                 priority="8185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('187') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('187') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '187' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70130') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70130' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit User Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Visit User Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8"
                 priority="8184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('188') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('188') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '188' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected Admit Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected Admit Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="8182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="8181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9"
                 priority="8179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('189') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('189') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '189' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected Discharge Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="8177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="8176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.10"
                 priority="8174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('711') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('711') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '711' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Estimated Length of Inpatient Stay' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.11"
                 priority="8173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('712') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('712') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '712' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Actual Length of Inpatient Stay' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.12"
                 priority="8172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('713') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('713') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '713' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Visit Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13"
                 priority="8171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('714') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('714') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '714' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Referral Source Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Referral Source Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="8169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="8168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="8161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="8160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="8159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="8158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="8157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="8156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="8155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="8149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="8147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="8146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="8144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="8142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="8136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="8134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="8124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="8112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="8110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="8105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="8100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="8099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="8086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.14"
                 priority="8073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('715') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('715') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '715' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Previous Service Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Previous Service Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.15"
                 priority="8072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('716') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('716') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '716' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Employment Illness Related Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Employment Illness Related Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.16"
                 priority="8070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('717') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('717') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '717' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70213') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70213' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Purge Status Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Purge Status Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.17"
                 priority="8069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('718') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('718') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '718' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Purge Status Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Purge Status Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.18"
                 priority="8068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('719') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('719') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '719' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70214') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70214' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Special Program Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Special Program Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.19"
                 priority="8067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('720') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('720') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '720' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Retention Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Retention Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.20"
                 priority="8065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('721') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('721') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '721' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected Number of Insurance Plans' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.21"
                 priority="8064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('722') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('722') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '722' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70215') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70215' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit Publicity Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Visit Publicity Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.22"
                 priority="8063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('723') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('723') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '723' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit Protection Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Visit Protection Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23"
                 priority="8061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('724') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('724') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '724' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'XON' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Clinic Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Clinic Organization Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="8059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="8058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="8057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="8056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="8055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="8053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="8051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="8050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="8049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="8047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="8045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="8043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="8042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="8041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="8039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="8037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.24"
                 priority="8036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('725') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('725') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '725' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70216') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70216' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Status Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Patient Status Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.25"
                 priority="8035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('726') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('726') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '726' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70217') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70217' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Visit Priority Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Visit Priority Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.26"
                 priority="8034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('727') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('727') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '727' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Previous Treatment Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Previous Treatment Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.27"
                 priority="8033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('728') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('728') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '728' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70112') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70112' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected Discharge Disposition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Disposition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.28"
                 priority="8032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('729') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('729') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '729' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Signature on File Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Signature on File Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.29"
                 priority="8031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('730') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('730') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '730' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('First Similar Illness Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'First Similar Illness Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30"
                 priority="8030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('731') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('731') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '731' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70218') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70218' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Patient Charge Adjustment Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="8028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="8027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="8026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="8024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="8023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="8022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.31"
                 priority="8020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('732') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('732') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '732' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70219') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70219' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Recurring Service Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Recurring Service Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.32"
                 priority="8019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('733') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('733') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '733' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Billing Media Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Billing Media Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33"
                 priority="8017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('734') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('734') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '734' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected Surgery Date and Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected Surgery Date and Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="8015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="8014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.34"
                 priority="8012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('735') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('735') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '735' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Military Partnership Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Military Partnership Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.35"
                 priority="8010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('736') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('736') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '736' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Military Non-Availability Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Military Non-Availability Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.36"
                 priority="8008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('737') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('737') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '737' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Newborn Baby Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Newborn Baby Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.37"
                 priority="8006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('738') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('738') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '738' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Baby Detained Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Baby Detained Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38"
                 priority="8004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1543') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1543') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1543' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70430') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70430' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Mode of Arrival Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Mode of Arrival Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="8002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="8001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="8000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="7998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="7997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="7996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39"
                 priority="7994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1544') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1544') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1544' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70431') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70431' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Recreational Drug Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Recreational Drug Use Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="7992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="7991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="7990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="7988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="7987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="7986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40"
                 priority="7984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1545') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1545') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1545' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70432') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70432' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Admission Level of Care Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Admission Level of Care Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="7982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="7981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="7980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="7978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="7977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="7976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41"
                 priority="7974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1546') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1546') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1546' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70433') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70433' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Precaution Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Precaution Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="7972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="7971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="7970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="7968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="7967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="7966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42"
                 priority="7964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1547') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1547') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1547' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70434') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70434' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Condition Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Patient Condition Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="7962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="7961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="7960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="7958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="7957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="7956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.43"
                 priority="7954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '759' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70315') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70315' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Living Will Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Living Will Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.44"
                 priority="7953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '760' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70316') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70316' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organ Donor Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45"
                 priority="7952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1548') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1548') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1548' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70435') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70435' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Advance Directive Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="7950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="7949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="7948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="7946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="7945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="7944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.46"
                 priority="7942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1549') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1549') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1549' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'DT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Status Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Patient Status Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47"
                 priority="7941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1550') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1550') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1550' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected LOA Return Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="7939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="7938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48"
                 priority="7936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1841') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1841') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1841' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Expected Pre-admission Testing Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="7934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="7933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.49"
                 priority="7931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1842') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1842') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Item MOET '1842' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70534') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @Table MOET 'HL70534' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Notify Clergy Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PV2_segment): de waarde van @LongName MOET 'Notify Clergy Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7167-false-d579342e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN"
                 priority="7930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:SPM is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:SPM komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.ORDER)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.ORDER)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.ORDER is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM"
                 priority="7929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.4)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.25)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.25)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.26)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.26)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.27)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.27)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.28)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.28)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPM.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.1"
                 priority="7928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1754') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1754') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1754' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID _ SPM') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID _ SPM') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Set ID _ SPM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2"
                 priority="7927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1755') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1755') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1755' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'EIP' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1"
                 priority="7925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="7923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="7922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="7921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="7920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2"
                 priority="7918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="7916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="7915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="7914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="7913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3"
                 priority="7911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1756') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1756') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1756' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'EIP' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Parent IDs') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Parent IDs') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Parent IDs' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1"
                 priority="7909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="7907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="7906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="7905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="7904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2"
                 priority="7902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="7900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="7899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="7898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="7897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4"
                 priority="7895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1900') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1900') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1900' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70487') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70487') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70487' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.1"
                 priority="7893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.2"
                 priority="7892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.3"
                 priority="7891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.4"
                 priority="7889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.5"
                 priority="7888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.6"
                 priority="7887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.7"
                 priority="7885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.8"
                 priority="7884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.9"
                 priority="7883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5"
                 priority="7882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1757') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1757') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1757' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70541') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70541') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70541' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Type Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Type Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Type Modifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.1"
                 priority="7880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.2"
                 priority="7879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.3"
                 priority="7878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.4"
                 priority="7876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.5"
                 priority="7875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.6"
                 priority="7874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.7"
                 priority="7872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.8"
                 priority="7871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.9"
                 priority="7870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6"
                 priority="7869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1758') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1758') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1758' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70371' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Additives' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.1"
                 priority="7867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.2"
                 priority="7866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.3"
                 priority="7865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.4"
                 priority="7863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.5"
                 priority="7862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.6"
                 priority="7861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.7"
                 priority="7859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.8"
                 priority="7858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.9"
                 priority="7857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7"
                 priority="7856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1759') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1759') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1759' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70488') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70488') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70488' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.1"
                 priority="7854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.2"
                 priority="7853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.3"
                 priority="7852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.4"
                 priority="7850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.5"
                 priority="7849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.6"
                 priority="7848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.7"
                 priority="7846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.8"
                 priority="7845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.9"
                 priority="7844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8"
                 priority="7843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1901') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1901') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1901' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Source Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Source Site' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.1"
                 priority="7841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.2"
                 priority="7840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.3"
                 priority="7839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.4"
                 priority="7837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.5"
                 priority="7836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.6"
                 priority="7835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.7"
                 priority="7833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.8"
                 priority="7832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.9"
                 priority="7831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9"
                 priority="7830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1760') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1760') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1760' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70542') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70542') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70542' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Source Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Source Site Modifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.1"
                 priority="7828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.2"
                 priority="7827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.3"
                 priority="7826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.4"
                 priority="7824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.5"
                 priority="7823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.6"
                 priority="7822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.7"
                 priority="7820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.8"
                 priority="7819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.9"
                 priority="7818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10"
                 priority="7817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1761') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1761') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1761' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70543') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70543') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70543' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Collection Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Site' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.1"
                 priority="7815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.2"
                 priority="7814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.3"
                 priority="7813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.4"
                 priority="7811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.5"
                 priority="7810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.6"
                 priority="7809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.7"
                 priority="7807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.8"
                 priority="7806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.9"
                 priority="7805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11"
                 priority="7804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1762') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1762') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1762' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70369' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Role' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.1"
                 priority="7802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.2"
                 priority="7801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.3"
                 priority="7800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.4"
                 priority="7798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.5"
                 priority="7797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.6"
                 priority="7796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.7"
                 priority="7794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.8"
                 priority="7793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.9"
                 priority="7792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12"
                 priority="7791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1902') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1902') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1902' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Collection Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Amount' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.1"
                 priority="7789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2"
                 priority="7788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="7786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="7785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="7784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="7782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="7781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="7780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.13"
                 priority="7778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1763') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1763') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1763' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Grouped Specimen Count') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Grouped Specimen Count') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Grouped Specimen Count' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.14"
                 priority="7777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1764') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1764') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1764' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15"
                 priority="7776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1908') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1908') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1908' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70376') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70376' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Handling Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Handling Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.1"
                 priority="7774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.2"
                 priority="7773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.3"
                 priority="7772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.4"
                 priority="7770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.5"
                 priority="7769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.6"
                 priority="7768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.7"
                 priority="7766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.8"
                 priority="7765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.9"
                 priority="7764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16"
                 priority="7763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1903') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1903') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1903' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70489') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70489') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70489' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Risk Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Risk Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Risk Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.1"
                 priority="7761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.2"
                 priority="7760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.3"
                 priority="7759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.4"
                 priority="7757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.5"
                 priority="7756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.6"
                 priority="7755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.7"
                 priority="7753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.8"
                 priority="7752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.9"
                 priority="7751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17"
                 priority="7750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1765') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1765') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1765' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Collection Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1"
                 priority="7748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2"
                 priority="7743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18"
                 priority="7738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('248') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '248' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.1"
                 priority="7736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.2"
                 priority="7735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19"
                 priority="7733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1904') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1904') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1904' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Expiration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Expiration Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.1"
                 priority="7731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.2"
                 priority="7730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.20"
                 priority="7728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1766') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1766') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1766' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Availability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Availability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Availability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21"
                 priority="7726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1767') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1767') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1767' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70490') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70490') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70490' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Reject Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Reject Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Reject Reason' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.1"
                 priority="7724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.2"
                 priority="7723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.3"
                 priority="7722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.4"
                 priority="7720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.5"
                 priority="7719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.6"
                 priority="7718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.7"
                 priority="7716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.8"
                 priority="7715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.9"
                 priority="7714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22"
                 priority="7713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1768') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1768') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1768' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70491') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70491') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70491' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Quality') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Quality') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Quality' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.1"
                 priority="7711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.2"
                 priority="7710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.3"
                 priority="7709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.4"
                 priority="7707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.5"
                 priority="7706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.6"
                 priority="7705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.7"
                 priority="7703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.8"
                 priority="7702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.9"
                 priority="7701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23"
                 priority="7700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1769') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1769') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1769' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70492') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70492') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70492' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Appropriateness') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Appropriateness') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Appropriateness' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.1"
                 priority="7698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.2"
                 priority="7697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.3"
                 priority="7696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.4"
                 priority="7694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.5"
                 priority="7693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.6"
                 priority="7692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.7"
                 priority="7690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.8"
                 priority="7689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.9"
                 priority="7688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24"
                 priority="7687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1770') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1770') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1770' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70493') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70493') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70493' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Condition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.1"
                 priority="7685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.2"
                 priority="7684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.3"
                 priority="7683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.4"
                 priority="7681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.5"
                 priority="7680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.6"
                 priority="7679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.7"
                 priority="7677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.8"
                 priority="7676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.9"
                 priority="7675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25"
                 priority="7674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1771') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1771') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1771' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Current Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Current Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.1"
                 priority="7672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2"
                 priority="7671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="7669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="7668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="7667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="7665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="7664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="7663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.26"
                 priority="7661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1772') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1772') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1772' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Specimen Containers') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Number of Specimen Containers') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Number of Specimen Containers' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27"
                 priority="7660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1773') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1773') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1773' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Container Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.1"
                 priority="7658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.2"
                 priority="7657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.3"
                 priority="7656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.4"
                 priority="7654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.5"
                 priority="7653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.6"
                 priority="7652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.7"
                 priority="7650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.8"
                 priority="7649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.9"
                 priority="7648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28"
                 priority="7647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1774') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1774') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1774' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70544') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70544') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70544' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Container Condition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.1"
                 priority="7645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.2"
                 priority="7644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.3"
                 priority="7643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.4"
                 priority="7641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.5"
                 priority="7640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.6"
                 priority="7639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.7"
                 priority="7637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.8"
                 priority="7636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.9"
                 priority="7635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29"
                 priority="7634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1775') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1775') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1775' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70494') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70494') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70494' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Child Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Child Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Child Role' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.1"
                 priority="7632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.2"
                 priority="7631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.3"
                 priority="7630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.4"
                 priority="7628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.5"
                 priority="7627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.6"
                 priority="7626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.7"
                 priority="7624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.8"
                 priority="7623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.9"
                 priority="7622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX"
                 priority="7621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='CNE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='CNE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '370133003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen substance (attribute)' codeSystemName='SNM' of code '118169006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source topography (attribute)' codeSystemName='SNM' of code '118171006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen procedure (attribute)' codeSystemName='SNM' of code '118168003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source morphology (attribute)' codeSystemName='SNM' of code '118170007' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source identity (attribute)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de elementwaarde MOET een zijn van 'code '370133003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen substance (attribute)' codeSystemName='SNM' of code '118169006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source topography (attribute)' codeSystemName='SNM' of code '118171006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen procedure (attribute)' codeSystemName='SNM' of code '118168003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source morphology (attribute)' codeSystemName='SNM' of code '118170007' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source identity (attribute)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.1"
                 priority="7604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.2"
                 priority="7603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.3"
                 priority="7602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.4"
                 priority="7600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.5"
                 priority="7599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.6"
                 priority="7598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.7"
                 priority="7596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.8"
                 priority="7595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.9"
                 priority="7594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='F'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.11 MOET ''F'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='F'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de element content van hl7v2:OBX.11 MOET ''F'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX"
                 priority="7435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7182-false-d595832e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER"
                 priority="7261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:SAC is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:SAC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:INV komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC"
                 priority="7260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.24)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.24)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.25)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.25)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.26)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.26)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.28)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.28)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.30)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.30)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.31)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.31)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.31 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.32)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.32)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.33)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.33)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.33 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.34)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.34)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.34 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.35)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.35)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.35 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.36)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.36)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.37)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.37)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.38)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.38)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.38 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.39)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.39)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.39 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.42)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAC.42)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): element hl7v2:SAC.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1"
                 priority="7259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1329') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1329') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1329' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('External Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('External Accession Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'External Accession Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.1"
                 priority="7257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.2"
                 priority="7256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.3"
                 priority="7255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.4"
                 priority="7254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2"
                 priority="7252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1330') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1330') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1330' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Accession Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Accession Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.1"
                 priority="7250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.2"
                 priority="7249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.3"
                 priority="7248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.4"
                 priority="7247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3"
                 priority="7245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1331') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1331') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1331' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Container Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.1"
                 priority="7243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.2"
                 priority="7242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.3"
                 priority="7241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.4"
                 priority="7240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4"
                 priority="7238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1332') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1332') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1332' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary (parent) Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Primary (parent) Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Primary (parent) Container Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.1"
                 priority="7236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.2"
                 priority="7235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.3"
                 priority="7234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.4"
                 priority="7233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5"
                 priority="7231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1333') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1333') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1333' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Equipment Container Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.1"
                 priority="7229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.2"
                 priority="7228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.3"
                 priority="7227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.4"
                 priority="7226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6"
                 priority="7224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('249') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '249' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SPS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'SPS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Specimen Source' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1"
                 priority="7222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="7220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="7219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="7218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="7216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="7215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="7214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="7212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="7211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="7210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2"
                 priority="7209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="7207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="7206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="7205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="7203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="7202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="7201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="7199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="7198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="7197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3"
                 priority="7196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape"
                 priority="7195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="7194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="7193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4"
                 priority="7192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70163') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Body Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="7190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="7189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="7188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="7186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="7185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="7184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="7182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="7181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="7180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5"
                 priority="7179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70495') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="7177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="7176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="7175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="7173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="7172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="7171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="7169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="7168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="7167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6"
                 priority="7166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="7164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="7163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="7162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="7160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="7159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="7158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="7156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="7155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="7154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7"
                 priority="7153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="7151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="7150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="7149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="7147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="7146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="7145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="7143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="7142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="7141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7"
                 priority="7140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1334') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1334') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1334' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Registration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Registration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Registration Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.1"
                 priority="7138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.2"
                 priority="7137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8"
                 priority="7135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1335') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1335') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1335' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70370') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70370') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70370' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Container Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.1"
                 priority="7133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.2"
                 priority="7132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.3"
                 priority="7131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.4"
                 priority="7129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.5"
                 priority="7128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.6"
                 priority="7127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9"
                 priority="7125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1336') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1336') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1336' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70378') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70378') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70378' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Carrier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Carrier Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Carrier Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.1"
                 priority="7123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.2"
                 priority="7122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.3"
                 priority="7121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.4"
                 priority="7119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.5"
                 priority="7118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.6"
                 priority="7117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10"
                 priority="7115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1337') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1337') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1337' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Carrier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Carrier Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.1"
                 priority="7113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.2"
                 priority="7112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.3"
                 priority="7111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.4"
                 priority="7110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11"
                 priority="7108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[matches(local-name(),'^NA\.\d+$')]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[. castable as xs:decimal]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1338') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1338') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1338' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NA') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NA') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NA' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position in Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Position in Carrier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Position in Carrier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.1"
                 priority="7106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.2"
                 priority="7105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.3"
                 priority="7104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value3') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value3' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.4"
                 priority="7103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value4') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value4' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12"
                 priority="7102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1339') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1339') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1339' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70379') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70379') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70379' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tray Type - SAC') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Tray Type - SAC') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Tray Type - SAC' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.1"
                 priority="7100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.2"
                 priority="7099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.3"
                 priority="7098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.4"
                 priority="7096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.5"
                 priority="7095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.6"
                 priority="7094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13"
                 priority="7092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1340') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1340') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1340' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tray Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Tray Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Tray Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.1"
                 priority="7090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.2"
                 priority="7089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.3"
                 priority="7088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.4"
                 priority="7087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14"
                 priority="7085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[matches(local-name(),'^NA\.\d+$')]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="*[. castable as xs:decimal]">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NA.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1341') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1341') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1341' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NA') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NA') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NA' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position in Tray') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Position in Tray') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Position in Tray' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.1"
                 priority="7083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.2"
                 priority="7082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.3"
                 priority="7081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value3') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value3' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.4"
                 priority="7080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value4') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NA_datatype): de waarde van @LongName MOET 'Value4' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15"
                 priority="7079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1342') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1342') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1342' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.1"
                 priority="7077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.2"
                 priority="7076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.3"
                 priority="7075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.4"
                 priority="7073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.5"
                 priority="7072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.6"
                 priority="7071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.16"
                 priority="7069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1343') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1343') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1343' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Height') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Height') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Container Height' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.17"
                 priority="7068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1344') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1344') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1344' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Diameter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Diameter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Container Diameter' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.18"
                 priority="7067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1345') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1345') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1345' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Barrier Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Barrier Delta') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Barrier Delta' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.19"
                 priority="7066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1346') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1346') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1346' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bottom Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bottom Delta') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Bottom Delta' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20"
                 priority="7065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1347') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1347') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1347' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Height/Diameter/Delta Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Height/Diameter/Delta Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Container Height/Diameter/Delta Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.1"
                 priority="7063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.2"
                 priority="7062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.3"
                 priority="7061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.4"
                 priority="7059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.5"
                 priority="7058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.6"
                 priority="7057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.21"
                 priority="7055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('644') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('644') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '644' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Container Volume' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.22"
                 priority="7054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1349') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1349') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1349' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Available Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Available Specimen Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Available Specimen Volume' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.23"
                 priority="7053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1350') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1350') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1350' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Initial Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Initial Specimen Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Initial Specimen Volume' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24"
                 priority="7052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1351') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1351') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1351' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Volume Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Volume Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Volume Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.1"
                 priority="7050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.2"
                 priority="7049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.3"
                 priority="7048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.4"
                 priority="7046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.5"
                 priority="7045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.6"
                 priority="7044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25"
                 priority="7042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1352') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1352') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1352' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70380') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70380') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70380' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Separator Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.1"
                 priority="7040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.2"
                 priority="7039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.3"
                 priority="7038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.4"
                 priority="7036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.5"
                 priority="7035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.6"
                 priority="7034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26"
                 priority="7032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1353') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1353') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1353' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70381') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70381') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70381' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cap Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Cap Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Cap Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.1"
                 priority="7030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.2"
                 priority="7029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.3"
                 priority="7028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.4"
                 priority="7026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.5"
                 priority="7025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.6"
                 priority="7024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27"
                 priority="7022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('647') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('647') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '647' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70371' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additive') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Additive') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Additive' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.1"
                 priority="7020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.2"
                 priority="7019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.3"
                 priority="7018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.4"
                 priority="7016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.5"
                 priority="7015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.6"
                 priority="7014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.7"
                 priority="7012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.8"
                 priority="7011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.9"
                 priority="7010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28"
                 priority="7009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1355') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1355') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1355' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Component') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Component') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Specimen Component' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.1"
                 priority="7007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.2"
                 priority="7006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.3"
                 priority="7005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.4"
                 priority="7003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.5"
                 priority="7002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.6"
                 priority="7001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29"
                 priority="6999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1356') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1356') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1356' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'SN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Dilution Factor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.1"
                 priority="6997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.2"
                 priority="6996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.3"
                 priority="6995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.4"
                 priority="6994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30"
                 priority="6993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1357') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1357') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1357' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70373') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70373') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70373' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Treatment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Treatment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Treatment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.1"
                 priority="6991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.2"
                 priority="6990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.3"
                 priority="6989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.4"
                 priority="6987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.5"
                 priority="6986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.6"
                 priority="6985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31"
                 priority="6983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1358') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1358') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1358' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'SN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temperature') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Temperature') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Temperature' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.1"
                 priority="6981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.2"
                 priority="6980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.3"
                 priority="6979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.4"
                 priority="6978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.32"
                 priority="6977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1359') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1359') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1359' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hemolysis Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Hemolysis Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Hemolysis Index' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33"
                 priority="6976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1360') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1360') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hemolysis Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Hemolysis Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Hemolysis Index Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.1"
                 priority="6974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.2"
                 priority="6973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.3"
                 priority="6972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.4"
                 priority="6970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.5"
                 priority="6969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.6"
                 priority="6968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.34"
                 priority="6966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1361') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1361') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1361' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lipemia Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Lipemia Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Lipemia Index' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35"
                 priority="6965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1362') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1362') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1362' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lipemia Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Lipemia Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Lipemia Index Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.1"
                 priority="6963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.2"
                 priority="6962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.3"
                 priority="6961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.4"
                 priority="6959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.5"
                 priority="6958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.6"
                 priority="6957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.36"
                 priority="6955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1363') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1363') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Icterus Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Icterus Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Icterus Index' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37"
                 priority="6954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1364') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1364') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1364' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Icterus Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Icterus Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Icterus Index Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.1"
                 priority="6952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.2"
                 priority="6951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.3"
                 priority="6950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.4"
                 priority="6948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.5"
                 priority="6947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.6"
                 priority="6946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.38"
                 priority="6944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1365') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1365') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1365' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fibrin Index') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Fibrin Index') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Fibrin Index' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39"
                 priority="6943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1366') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1366') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1366' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fibrin Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Fibrin Index Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Fibrin Index Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.1"
                 priority="6941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.2"
                 priority="6940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.3"
                 priority="6939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.4"
                 priority="6937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.5"
                 priority="6936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.6"
                 priority="6935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40"
                 priority="6933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1367') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1367') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1367' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70374') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70374') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70374' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('System Induced Contaminants') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('System Induced Contaminants') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'System Induced Contaminants' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.1"
                 priority="6931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.2"
                 priority="6930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.3"
                 priority="6929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.4"
                 priority="6927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.5"
                 priority="6926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.6"
                 priority="6925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41"
                 priority="6923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1368') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1368') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1368' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70382') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70382') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70382' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Drug Interference') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Drug Interference') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Drug Interference' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.1"
                 priority="6921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.2"
                 priority="6920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.3"
                 priority="6919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.4"
                 priority="6917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.5"
                 priority="6916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.6"
                 priority="6915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42"
                 priority="6913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1369') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1369') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1369' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70375') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70375') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70375' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Artificial Blood') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Artificial Blood') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Artificial Blood' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.1"
                 priority="6911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.2"
                 priority="6910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.3"
                 priority="6909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.4"
                 priority="6907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.5"
                 priority="6906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.6"
                 priority="6905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43"
                 priority="6903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1370') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1370') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1370' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70376') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70376' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Special Handling Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Special Handling Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.1"
                 priority="6901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.2"
                 priority="6900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.3"
                 priority="6899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.4"
                 priority="6897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.5"
                 priority="6896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.6"
                 priority="6895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.7"
                 priority="6893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.8"
                 priority="6892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.9"
                 priority="6891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44"
                 priority="6890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1371') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1371') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Item MOET '1371' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70377') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70377') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @Table MOET 'HL70377' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Environmental Factors') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Environmental Factors') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAC_segment): de waarde van @LongName MOET 'Other Environmental Factors' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.1"
                 priority="6888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.2"
                 priority="6887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.3"
                 priority="6886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.4"
                 priority="6884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.5"
                 priority="6883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.6"
                 priority="6882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV"
                 priority="6880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:INV.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): element hl7v2:INV.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1"
                 priority="6879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1372') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1372') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1372' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70451') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70451') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Table MOET 'HL70451' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Substance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Substance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.1"
                 priority="6877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.2"
                 priority="6876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.3"
                 priority="6875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.4"
                 priority="6873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.5"
                 priority="6872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.6"
                 priority="6871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2"
                 priority="6869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1373') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1373') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1373' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70383') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70383') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Table MOET 'HL70383' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Substance Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Substance Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.1"
                 priority="6867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.2"
                 priority="6866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.3"
                 priority="6865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.4"
                 priority="6863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.5"
                 priority="6862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.6"
                 priority="6861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3"
                 priority="6859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1374') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1374') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1374' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70384') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70384') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Table MOET 'HL70384' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Substance Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Substance Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.1"
                 priority="6857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.2"
                 priority="6856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.3"
                 priority="6855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.4"
                 priority="6853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.5"
                 priority="6852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.6"
                 priority="6851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4"
                 priority="6849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1532') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1532') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1532' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Inventory Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Inventory Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Inventory Container Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.1"
                 priority="6847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.2"
                 priority="6846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.3"
                 priority="6845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.4"
                 priority="6843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.5"
                 priority="6842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.6"
                 priority="6841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5"
                 priority="6839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1376') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1376') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1376' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Container Carrier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Container Carrier Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.1"
                 priority="6837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.2"
                 priority="6836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.3"
                 priority="6835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.4"
                 priority="6833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.5"
                 priority="6832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.6"
                 priority="6831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6"
                 priority="6829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1377') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1377') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1377' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position on Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Position on Carrier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Position on Carrier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.1"
                 priority="6827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.2"
                 priority="6826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.3"
                 priority="6825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.4"
                 priority="6823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.5"
                 priority="6822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.6"
                 priority="6821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.7"
                 priority="6819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1378') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1378') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1378' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Initial Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Initial Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Initial Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.8"
                 priority="6818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1379') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1379') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1379' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Current Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Current Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.9"
                 priority="6817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1380') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1380') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1380' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Available Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Available Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Available Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.10"
                 priority="6816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1381') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1381') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1381' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Consumption Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Consumption Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Consumption Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11"
                 priority="6815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1382') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1382') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1382' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Quantity Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.1"
                 priority="6813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.2"
                 priority="6812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.3"
                 priority="6811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.4"
                 priority="6809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.5"
                 priority="6808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.6"
                 priority="6807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12"
                 priority="6805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1383') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1383') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1383' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Expiration Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/hl7v2:TS.1"
                 priority="6803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/hl7v2:TS.2"
                 priority="6802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13"
                 priority="6800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1384') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1384') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1384' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('First Used Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('First Used Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'First Used Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/hl7v2:TS.1"
                 priority="6798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/hl7v2:TS.2"
                 priority="6797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14"
                 priority="6795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1385') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1385') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1385' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'TQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('On Board Stability Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('On Board Stability Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'On Board Stability Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1"
                 priority="6793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="6791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="6790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2"
                 priority="6780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'RI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="6778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="6777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.3"
                 priority="6776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4"
                 priority="6775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="6773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="6772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5"
                 priority="6770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="6768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="6767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.6"
                 priority="6765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.7"
                 priority="6764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8"
                 priority="6763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape"
                 priority="6762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="6761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.9"
                 priority="6759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10"
                 priority="6757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="6755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="6753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="6752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="6751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="6750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="6749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="6748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="6747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="6746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="6744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="6743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11"
                 priority="6741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="6739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="6738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="6737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="6735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="6734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="6733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.12"
                 priority="6731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15"
                 priority="6730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1386') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1386') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1386' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Test/Fluid Identifier(s)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Test/Fluid Identifier(s)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Test/Fluid Identifier(s)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.1"
                 priority="6728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.2"
                 priority="6727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.3"
                 priority="6726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.4"
                 priority="6724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.5"
                 priority="6723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.6"
                 priority="6722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.16"
                 priority="6720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1387') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1387') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1387' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Manufacturer Lot Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Manufacturer Lot Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Manufacturer Lot Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17"
                 priority="6719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('286') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('286') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '286' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70385') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70385') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Table MOET 'HL70385' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Manufacturer Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Manufacturer Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Manufacturer Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.1"
                 priority="6717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.2"
                 priority="6716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.3"
                 priority="6715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.4"
                 priority="6713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.5"
                 priority="6712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.6"
                 priority="6711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18"
                 priority="6709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1389') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1389') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1389' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70386') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70386') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Table MOET 'HL70386' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Supplier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Supplier Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Supplier Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.1"
                 priority="6707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.2"
                 priority="6706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.3"
                 priority="6705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.4"
                 priority="6703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.5"
                 priority="6702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.6"
                 priority="6701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19"
                 priority="6699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1626') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1626') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1626' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('On Board Stability Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('On Board Stability Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'On Board Stability Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.1"
                 priority="6697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2"
                 priority="6696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20"
                 priority="6686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1896') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1896') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Item MOET '1896' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Target Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Target Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(INV_segment): de waarde van @LongName MOET 'Target Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.1"
                 priority="6684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2"
                 priority="6683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7189-false-d610371e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER"
                 priority="6673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBR is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBR komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:ORC is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:ORC komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="count(hl7v2:OUL_R22.RESULT)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OUL_R22.RESULT komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR"
                 priority="6672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.4)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.4 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.24)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.24 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.25)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.26)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.30)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.32)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.32 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.36)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.36 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.37)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.37 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.40)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.40 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.41)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.41 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.42)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.42 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.44)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.44 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.48)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.48 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBR.49)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): element hl7v2:OBR.49 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.1"
                 priority="6671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('237') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('237') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '237' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBR') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Set ID - OBR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2"
                 priority="6670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('216') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '216' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Order Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="6668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="6667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="6666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="6665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3"
                 priority="6663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('217') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '217' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler Order Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="6661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="6660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="6659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="6658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4"
                 priority="6656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('238') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '238' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal Service Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Universal Service Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="6654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="6653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="6652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="6650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="6649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="6648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.5"
                 priority="6646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('239') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('239') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '239' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Priority _ OBR') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Priority _ OBR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6"
                 priority="6644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('240') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('240') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '240' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Requested Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Requested Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="6642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="6641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7"
                 priority="6639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('241') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('241') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '241' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="6637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="6636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8"
                 priority="6634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('242') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('242') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '242' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="6632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="6631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9"
                 priority="6629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('243') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('243') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '243' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Collection Volume') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Collection Volume' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="6627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="6626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10"
                 priority="6616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('244') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('244') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '244' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Collector Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Collector Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="6614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="6613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="6611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="6610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="6609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="6608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="6607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="6606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="6605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="6604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="6603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="6602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="6601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="6600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="6598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="6597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="6596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="6594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="6592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="6591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="6589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="6587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="6585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="6581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="6579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="6569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="6557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="6555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="6550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="6545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="6544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="6531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.11"
                 priority="6518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('245') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('245') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '245' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70065') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70065' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Action Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Specimen Action Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12"
                 priority="6516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('246') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('246') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '246' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Danger Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Danger Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="6514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="6513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="6512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="6510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="6509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="6508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.13"
                 priority="6506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('247') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('247') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '247' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Relevant Clinical Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Relevant Clinical Information' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14"
                 priority="6505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('248') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '248' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="6503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="6502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15"
                 priority="6500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SPS.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('249') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '249' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SPS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'SPS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Source') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Specimen Source' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="6498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="6496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="6495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="6494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="6492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="6491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="6490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="6488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="6487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="6486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="6485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70371') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Additives') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="6483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="6482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="6481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="6479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="6478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="6477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="6475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="6474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="6473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="6472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Collection Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="6471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="6470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="6468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70163') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Body Site') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="6466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="6465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="6464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="6462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="6461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="6460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="6458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="6457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="6456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="6455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70495') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Site Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="6453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="6452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="6451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="6449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="6448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="6447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="6445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="6444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="6443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="6442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="6440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="6439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="6438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="6436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="6435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="6434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="6432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="6431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="6430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="6429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70369') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Specimen Role') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="6427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="6426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="6425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="6423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="6422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="6421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="6419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="6418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="6417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16"
                 priority="6416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '226' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ordering Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Provider' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="6414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="6413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="6411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="6410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="6409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="6408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="6407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="6406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="6405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="6404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="6403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="6402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="6401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="6400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="6398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="6397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="6396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="6394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="6392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="6391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="6389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="6387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="6385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="6381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="6379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="6369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="6357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="6355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="6350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="6345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="6344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="6331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17"
                 priority="6318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('250') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('250') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '250' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XTN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Callback Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Callback Phone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="6316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="6315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="6313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="6311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="6310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="6309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="6308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="6307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="6306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="6305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="6304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="6303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.18"
                 priority="6302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('251') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('251') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '251' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Field 1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Field 1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.19"
                 priority="6301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('252') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('252') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '252' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Field 2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Field 2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.20"
                 priority="6300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('253') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('253') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '253' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Field 1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler Field 1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.21"
                 priority="6299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('254') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('254') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '254' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Field 2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler Field 2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22"
                 priority="6298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('255') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('255') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '255' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="6296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="6295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23"
                 priority="6293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MOC.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MOC.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('256') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('256') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '256' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('MOC') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'MOC' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Charge to Practice') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Charge to Practice' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="6291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MO.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:MO.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('MO') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van @Type MOET 'MO' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Monetary Amount') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van @LongName MOET 'Monetary Amount' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="6289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="6288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Denomination') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="6286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Charge Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(MOC_datatype): de waarde van @LongName MOET 'Charge Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="6284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="6283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="6282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="6280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="6279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="6278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.24"
                 priority="6276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('257') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('257') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '257' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70074') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70074' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Diagnostic Serv Sect ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.25"
                 priority="6274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('258') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('258') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '258' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70123') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70123' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26"
                 priority="6272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PRL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('259') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('259') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '259' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PRL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'PRL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Parent Result') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Parent Result' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="6270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Parent Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="6268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="6267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="6266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="6264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="6263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="6262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="6260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Sub-identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="6259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Value Descriptor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="6258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="6257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27"
                 priority="6255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('221') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '221' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity/Timing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Quantity/Timing' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="6253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="6251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="6250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="6240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'RI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="6238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="6237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="6236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="6235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="6233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="6232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="6230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="6228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="6227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="6225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="6224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="6223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="6222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="6221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="6219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="6217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="6215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="6213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="6212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="6211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="6210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="6209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="6208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="6207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="6206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="6204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="6203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="6201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="6199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="6198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="6197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="6195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="6194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="6193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="6191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28"
                 priority="6190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('260') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('260') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '260' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Result Copies To') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Result Copies To' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="6188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="6187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="6185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="6184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="6183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="6182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="6181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="6180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="6179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="6178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="6177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="6176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="6175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="6174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="6172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="6171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="6170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="6168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="6166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="6165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="6163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="6161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="6159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="6155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="6153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="6143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="6131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="6129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="6124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="6119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="6118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="6105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29"
                 priority="6092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('261') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('261') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '261' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EIP' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Parent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Parent' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="6090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="6088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="6087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="6086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="6085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="6083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="6081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="6080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="6079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="6078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.30"
                 priority="6076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('262') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('262') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '262' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70124') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70124' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transportation Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Transportation Mode' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31"
                 priority="6074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('263') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('263') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '263' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Reason for Study') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Reason for Study' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="6072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="6071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="6070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="6068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="6067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="6066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32"
                 priority="6064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('264') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('264') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '264' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NDL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Principal Result Interpreter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Principal Result Interpreter' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="6062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="6060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="6059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="6058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="6057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="6056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="6055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="6054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="6053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="6052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="6051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="6050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="6048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="6046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="6045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="6043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="6041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="6040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="6038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="6037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="6036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="6035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="6033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="6032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="6031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="6029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="6028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="6027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="6026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33"
                 priority="6025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('265') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('265') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '265' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NDL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assistant Result Interpreter') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Assistant Result Interpreter' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="6023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="6021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="6020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="6019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="6018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="6017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="6016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="6015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="6014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="6013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="6012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="6011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="6009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="6007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="6006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="6004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="6002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="6001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="5999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="5998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="5997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="5996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="5994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="5993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="5992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="5990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="5989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="5988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="5987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34"
                 priority="5986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('266') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('266') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '266' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NDL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Technician') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Technician' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="5984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="5982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="5981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="5980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="5979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="5978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="5977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="5976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="5975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="5974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="5973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="5972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="5970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="5968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="5967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="5965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="5963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="5962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="5960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="5959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="5958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="5957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="5955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="5954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="5953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="5951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="5950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="5949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="5948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35"
                 priority="5947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NDL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('267') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('267') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '267' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NDL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NDL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transcriptionist') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Transcriptionist' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="5945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CNN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="5943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="5942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="5941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="5940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="5939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="5938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="5937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="5936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="5935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="5934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="5933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="5931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="5929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="5928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="5926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="5924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="5923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="5921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="5920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="5919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="5918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="5916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="5915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="5914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="5912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="5911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Patient Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="5910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="5909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36"
                 priority="5908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('268') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('268') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '268' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Scheduled Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Scheduled Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="5906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="5905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.37"
                 priority="5903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1028') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1028') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1028' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Number of Sample Containers *') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Number of Sample Containers *' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38"
                 priority="5902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1029') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1029') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1029' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Transport Logistics of Collected Sample' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="5900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="5899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="5898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="5896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="5895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="5894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39"
                 priority="5892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1030') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1030') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1030' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Collector''s Comment *') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Collector''s Comment *' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="5890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="5889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="5888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="5886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="5885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="5884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40"
                 priority="5882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1031') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1031') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1031' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Transport Arrangement Responsibility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="5880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="5879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="5878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="5876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="5875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="5874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.41"
                 priority="5872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1032') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1032') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1032' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70224') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70224' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Transport Arranged') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Transport Arranged' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.42"
                 priority="5870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1033') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1033') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1033' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70225') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70225' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Escort Required') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Escort Required' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43"
                 priority="5868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1034') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1034') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1034' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Planned Patient Transport Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Planned Patient Transport Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="5866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="5865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="5864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="5862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="5861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="5860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44"
                 priority="5858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('393') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('393') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '393' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70088') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70088' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Procedure Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Procedure Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="5856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="5855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="5854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="5852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="5851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="5850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45"
                 priority="5848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1316') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1316') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1316' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70340') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70340' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Procedure Code Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Procedure Code Modifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="5846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="5845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="5844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="5842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="5841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="5840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46"
                 priority="5838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1474') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1474') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1474' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70411') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70411' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Supplemental Service Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Supplemental Service Information' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="5836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="5835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="5834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="5832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="5831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="5830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47"
                 priority="5828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1475') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1475') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1475' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70411') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70411' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Supplemental Service Information') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler Supplemental Service Information' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="5826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="5825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="5824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="5822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="5821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="5820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48"
                 priority="5818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1646') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1646') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1646' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70476') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70476' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="5816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="5815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="5814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="5812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="5811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="5810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="5808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="5807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="5806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.49"
                 priority="5805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1647') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1647') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1647' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70507') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70507' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Result Handling') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.34-2015-07-21T171850.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBR_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Result Handling' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC"
                 priority="5804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.25)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.25 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.26)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.26 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.27)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.27 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.28)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.28 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.29)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.29 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:ORC.30)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.30 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.1"
                 priority="5803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('215') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('215') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '215' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70119') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70119' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Control') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Control' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2"
                 priority="5801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('216') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '216' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Order Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="5799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="5798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="5797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="5796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3"
                 priority="5794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('217') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '217' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler Order Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="5792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="5791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="5790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="5789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4"
                 priority="5787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('218') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('218') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '218' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Group Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Group Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="5785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="5784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="5783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="5782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.5"
                 priority="5780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('219') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('219') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '219' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70038') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70038' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.6"
                 priority="5778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('220') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('220') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '220' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70121') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70121' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Response Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Response Flag' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7"
                 priority="5776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('221') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '221' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity/Timing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Quantity/Timing' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="5774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="5772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="5771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="5769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="5768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="5767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="5765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="5764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="5763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="5761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('RI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'RI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="5759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="5758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Explicit Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="5757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="5756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="5754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="5753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="5751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="5749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="5748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="5746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="5745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Condition') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="5744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="5743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="5742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="5741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="5740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70472') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="5738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OSD.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('OSD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Sequencing') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="5736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70524') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="5734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="5733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="5732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="5731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="5730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence Condition Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="5729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="5728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="5727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="5725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="5724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="5722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Occurrence Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="5720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="5719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="5718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="5716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="5715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="5714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="5712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total Occurrences') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8"
                 priority="5711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EIP.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('222') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('222') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '222' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EIP') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EIP' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Parent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Parent' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="5709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="5707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="5706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="5705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="5704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="5702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="5700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="5699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="5698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="5697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9"
                 priority="5695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('223') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('223') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '223' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of Transaction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of Transaction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="5693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="5692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10"
                 priority="5690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('224') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('224') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '224' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entered By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Entered By' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="5688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="5687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="5680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="5679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="5678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="5677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="5676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="5675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="5674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="5668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="5666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="5665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="5663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="5661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="5655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="5653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="5643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="5631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="5629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="5624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="5619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="5618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="5605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11"
                 priority="5592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('225') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('225') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '225' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Verified By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Verified By' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="5590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="5589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="5582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="5581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="5580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="5579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="5578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="5577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="5576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="5570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="5568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="5567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="5565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="5563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="5557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="5555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="5545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="5533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="5531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="5526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="5521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="5520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="5507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12"
                 priority="5494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('226') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '226' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ordering Provider') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Provider' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="5492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="5491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="5484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="5483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="5482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="5481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="5480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="5479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="5478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="5472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="5470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="5469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="5467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="5465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="5459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="5457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="5447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="5435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="5433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="5428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="5423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="5422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="5409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13"
                 priority="5396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:PL.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('227') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('227') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '227' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('PL') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'PL' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Enterer''s Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Enterer''s Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="5394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70302') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Point of Care') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="5393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70303') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Room') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Room' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="5392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70304') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Bed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="5391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="5389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="5388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="5387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="5385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70306') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="5384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70305') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Person Location Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="5383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70307') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Building') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Building' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="5382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70308') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Floor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="5381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Location Description') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="5380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="5378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="5377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="5376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="5375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="5373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="5371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="5370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="5369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14"
                 priority="5367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('228') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('228') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '228' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XTN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Call Back Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Call Back Phone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="5365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="5364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="5362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="5360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="5359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="5358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="5357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="5356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="5355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="5354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="5353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="5352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15"
                 priority="5351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('229') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('229') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '229' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Effective Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Effective Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="5349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="5348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16"
                 priority="5346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('230') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('230') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '230' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Control Code Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Control Code Reason' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="5344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="5343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="5342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="5340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="5339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="5338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17"
                 priority="5336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('231') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('231') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '231' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entering Organization') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Entering Organization' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="5334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="5333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="5332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="5330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="5329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="5328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18"
                 priority="5326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('232') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('232') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '232' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entering Device') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Entering Device' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="5324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="5323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="5322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="5320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="5319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="5318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19"
                 priority="5316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('233') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('233') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '233' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Action By') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Action By' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="5314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="5313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="5306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="5305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="5304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="5303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="5302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="5301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="5300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="5294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="5292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="5291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="5289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="5287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="5281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="5279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="5269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="5257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="5255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="5250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="5245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="5244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="5231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20"
                 priority="5218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1310') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1310') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1310' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70339') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70339' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Advanced Beneficiary Notice Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="5216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="5215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="5214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="5212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="5211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="5210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21"
                 priority="5208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XON.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1311') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1311') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1311' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XON') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XON' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ordering Facility Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Facility Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="5206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="5205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70204') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="5204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="5203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="5202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="5200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="5194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="5192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="5186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="5184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Organization Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22"
                 priority="5183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1312') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1312') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1312' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XAD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ordering Facility Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Facility Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="5181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="5179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="5178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="5177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="5176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="5175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="5174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="5173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="5172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="5170"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="5168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="5167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="5166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="5165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="5163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="5161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="5156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="5151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="5149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="5148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="5146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="5144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="5143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23"
                 priority="5141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XTN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1313') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1313') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1313' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XTN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XTN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ordering Facility Phone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Facility Phone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="5139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telephone Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="5138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70201') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="5136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70202') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="5134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Email Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="5133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="5132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Area/City Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="5131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Local Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="5130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="5129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Any Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="5128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Extension Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="5127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Speed Dial Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="5126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24"
                 priority="5125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XAD.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1314') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1314') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1314' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XAD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Ordering Provider Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Provider Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="5123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SAD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SAD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="5121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street or Mailing Address') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="5120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Street Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="5119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Dwelling Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="5118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="5117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('City') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="5116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('State or Province') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="5115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Zip or Postal Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="5114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70399') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Country') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="5112"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70190') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="5110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Other Geographic Designation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="5109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70289') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('County/Parish Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="5108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70288') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Census Tract') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="5107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="5105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Address Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="5103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="5098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="5093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="5091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="5090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="5088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="5086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="5085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25"
                 priority="5083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1473') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1473') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1473' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Status Modifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Status Modifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="5081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="5080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="5079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="5077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="5076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="5075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="5073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="5072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="5071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26"
                 priority="5070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1641') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1641') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1641' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70552') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70552' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="5068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="5067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="5066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="5064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="5063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="5062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="5060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="5059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="5058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27"
                 priority="5057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1642') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1642') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1642' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler''s Expected Availability Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="5055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="5054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28"
                 priority="5052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('615') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('615') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '615' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70177') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70177' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Confidentiality Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Confidentiality Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="5050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="5049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="5048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="5046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="5045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="5044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="5042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="5041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="5040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29"
                 priority="5039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1643') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1643') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1643' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70482') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70482' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Order Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="5037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="5036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="5035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="5033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="5032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="5031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="5029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="5028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="5027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30"
                 priority="5026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CNE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1644') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1644') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1644' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CNE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CNE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70483') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70483' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Enterer Authorization Mode') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Enterer Authorization Mode' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="5024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="5023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="5022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="5020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="5019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="5018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="5016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="5015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="5014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE"
                 priority="5013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.1"
                 priority="5012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '96' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.2"
                 priority="5011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '97' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3"
                 priority="5009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '98' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'FT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="5008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="5007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="5006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4"
                 priority="5005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '1318' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="5003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="5002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="5001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="4999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="4998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="4997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7197-false-d651171e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY"
                 priority="4995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:TQ1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:TQ1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1"
                 priority="4994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ1.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="4993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1627') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1627') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1627' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - TQ1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - TQ1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="4992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1628') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1628') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1628' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="4990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="4989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="4979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:RPT.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1629') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1629') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1629' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('RPT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'RPT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70335' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Repeat Pattern') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Repeat Pattern' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="4977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70335') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Table MOET 'HL70335' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Repeat Pattern Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Repeat Pattern Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="4975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="4974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="4973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="4971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="4970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="4969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="4967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="4966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="4965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="4964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70527') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Table MOET 'HL70527' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Calendar Alignment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Calendar Alignment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="4962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Phase Range Begin Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Phase Range Begin Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="4961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Phase Range End Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Phase Range End Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="4960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Period Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Period Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="4959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Period Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Period Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="4958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Institution Specified Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Institution Specified Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="4956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70528') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Table MOET 'HL70528' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Event') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Event' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="4954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Event Offset Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="4953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Event Offset Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="4952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('GTS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @Type MOET 'GTS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('General Timing Specification') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(RPT_datatype): de waarde van @LongName MOET 'General Timing Specification' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="4951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1630') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1630') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1630' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Explicit Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Explicit Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="4950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1631') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1631') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1631' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Relative Time and Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Relative Time and Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="4948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="4947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="4937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1632') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1632') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1632' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Service Duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Service Duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="4935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="4934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="4924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1633') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1633') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1633' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Start date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Start date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="4922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="4921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="4919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1634') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1634') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1634' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('End date/time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'End date/time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="4917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="4916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="4914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1635') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1635') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1635' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70485') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70485' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Priority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Priority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="4912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="4911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="4910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="4908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="4907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="4906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="4904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="4903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="4902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="4901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1636') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1636') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1636' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Condition text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Condition text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="4900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="4899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="4898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="4897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1637') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1637') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1637' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TX') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text instruction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Text instruction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="4896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TX_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="4895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="4894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="4893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1638') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1638') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1638' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70427') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70427' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Conjunction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Conjunction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="4891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1639') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1639') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1639' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Occurrence duration') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Occurrence duration' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="4889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="4888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="4878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1640') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1640') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1640' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Total occurrence''s') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Total occurrence''s' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2"
                 priority="4877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TQ2.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="4876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1648') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1648') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1648' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - TQ2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Set ID - TQ2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="4875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1649') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1649') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1649' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70503') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Table MOET 'HL70503' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Sequence/Results Flag' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="4873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1650') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1650') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1650' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Related Placer Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="4871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="4870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="4869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="4868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="4866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1651') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1651') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1651' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Related Filler Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Related Filler Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="4864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="4863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="4862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="4861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="4859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1652') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1652') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1652' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Related Placer Group Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Group Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="4857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="4856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="4855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="4854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="4852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1653') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1653') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1653' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70504') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Table MOET 'HL70504' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence Condition Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="4850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1654') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1654') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1654' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70505') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Table MOET 'HL70505' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Entry/Exit Indicator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="4848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CQ.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1655') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1655') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1655' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CQ') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'CQ' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sequence Condition Time Interval') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Time Interval' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="4846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Quantity') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="4845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="4835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1656') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1656') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1656' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="4834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1657') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1657') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Item MOET '1657' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70506') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @Table MOET 'HL70506' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Special Service Request Relationship') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TQ2_segment): de waarde van @LongName MOET 'Special Service Request Relationship' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7204-false-d655107e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION"
                 priority="4832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="4831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="4830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="4829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text()='CNE' or text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE' of 'ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="text()='CNE' or text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de element content van hl7v2:OBX.2 MOET ''CNE' of 'ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="4827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '55607006' codeSystem '2.16.840.1.113883.6.96' displayName='Problem (finding)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de elementwaarde MOET een zijn van 'code '55607006' codeSystem '2.16.840.1.113883.6.96' displayName='Problem (finding)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="4825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="4824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="4823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="4821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="4820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="4819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="4817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="4816"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.86-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NM_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1]/conceptList/exception[@code = $theNullFlavor][@codeSystem = '2.16.840.1.113883.5.1008'])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or $validNullFlavorsFound"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or $validNullFlavorsFound">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.86-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NM_datatype): de nulwaarde '<xsl:text/>
                  <xsl:value-of select="@nullFlavor"/>
                  <xsl:text/>' voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardelijst 2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1]/conceptList/exception[@code = $theNullFlavor][@codeSystem = '2.16.840.1.113883.5.1008'])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or $validNullFlavorsFound"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(@nullFlavor) or $validNullFlavorsFound">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de nulwaarde '<xsl:text/>
                  <xsl:value-of select="@nullFlavor"/>
                  <xsl:text/>' voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardelijst 2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07).</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="4814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='kg') or (@code='g')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='kg') or (@code='g')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="4812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="4811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="4810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="4808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="4807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="4806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="4804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="4803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="4802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="4801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="4799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="4797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="4795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="4794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="4792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="4791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="4789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="4788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="4786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="4784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="4783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="4782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="4780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="4779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="4778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="4776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="4774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="4773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="4766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="4765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="4764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="4763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="4762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="4761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="4760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="4754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="4752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="4751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="4749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="4747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="4741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="4739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="4729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="4717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="4715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="4710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="4705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="4704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="4691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="4678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="4676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="4675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="4674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="4672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="4671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="4670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="4668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="4666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="4665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="4664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="4663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="4661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="4659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="4658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7213-false-d659384e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="4656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="4655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="4654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="4653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="4651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '282291009' codeSystem '2.16.840.1.113883.6.96' displayName='Diagnosis interpretation (observable entity)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de elementwaarde MOET een zijn van 'code '282291009' codeSystem '2.16.840.1.113883.6.96' displayName='Diagnosis interpretation (observable entity)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="4649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="4648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="4647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="4645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="4644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="4643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="4641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="4640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="4639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="4637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="4636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="4635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="4633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="4632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="4631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="4629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="4628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="4627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="4626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="4624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="4622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="4620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="4619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="4617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="4616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="4614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="4613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="4611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="4609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="4608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="4607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="4605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="4604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="4603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="4601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="4599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="4598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="4591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="4590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="4589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="4588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="4587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="4586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="4585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="4579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="4577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="4576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="4574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="4572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="4566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="4564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="4554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="4542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="4540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="4535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="4530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="4529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="4516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="4503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="4501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="4500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="4499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="4497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="4496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="4495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="4493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="4491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="4490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="4489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="4488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="4486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="4484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="4483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7221-false-d663605e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="4481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="4480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="4479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="4478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="4476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '29463-7' codeSystem '2.16.840.1.113883.6.1' displayName='Body weight' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de elementwaarde MOET een zijn van 'code '29463-7' codeSystem '2.16.840.1.113883.6.1' displayName='Body weight' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="4474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="4473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="4472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="4470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="4469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="4468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="4466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="4465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="4464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='kg') or (@code='g')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='kg') or (@code='g')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="4462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="4461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="4460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="4458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="4457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="4456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="4454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="4453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="4452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="4451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="4449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="4447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="4445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="4444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="4442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="4441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="4439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="4438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="4436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="4434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="4433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="4432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="4430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="4429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="4428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="4426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="4424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="4423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="4416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="4415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="4414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="4413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="4412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="4411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="4410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="4404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="4402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="4401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="4399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="4397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="4391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="4389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="4379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="4367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="4365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="4360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="4355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="4354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="4341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="4328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="4326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="4325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="4324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="4322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="4321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="4320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="4318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="4316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="4315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="4314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="4313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="4311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="4309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="4308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7229-false-d667855e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="4306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="4305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="4304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="4303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="4301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '8302-2' codeSystem '2.16.840.1.113883.6.1' displayName='Body height' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de elementwaarde MOET een zijn van 'code '8302-2' codeSystem '2.16.840.1.113883.6.1' displayName='Body height' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="4299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="4298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="4297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="4295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="4294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="4293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="4291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="4290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="4289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='cm')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='cm')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code 'cm''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='cm')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='cm')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de elementwaarde MOET een zijn van 'code 'cm''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="4287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="4286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="4285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="4283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="4282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="4281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="4279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="4278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="4277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="4276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="4274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="4272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="4270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="4269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="4267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="4266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="4264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="4263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="4261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="4259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="4258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="4257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="4255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="4254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="4253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="4251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="4249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="4248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="4241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="4240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="4239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="4238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="4237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="4236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="4235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="4229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="4227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="4226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="4224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="4222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="4216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="4214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="4204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="4192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="4190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="4185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="4180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="4179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="4166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="4153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="4151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="4150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="4149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="4147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="4146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="4145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="4143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="4141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="4140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="4139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="4138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="4136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lengte): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="4134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="4133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7237-false-d672099e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="4131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="4130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="4129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="4128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="4126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '11368-8' codeSystem '2.16.840.1.113883.6.1' displayName='Illness or injury onset date and time' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de elementwaarde MOET een zijn van 'code '11368-8' codeSystem '2.16.840.1.113883.6.1' displayName='Illness or injury onset date and time' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="4124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="4123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="4122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="4120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="4119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="4118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="4116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="4115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="4113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="4112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="4110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="4108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="4107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="4106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="4104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="4103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="4102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="4100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="4099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="4098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="4097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="4095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="4093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="4091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="4090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="4088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="4087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="4085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="4084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="4082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="4080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="4079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="4078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="4076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="4075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="4074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="4072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="4070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="4069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="4062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="4061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="4060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="4059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="4058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="4057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="4056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="4050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="4048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="4047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="4045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="4043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="4037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="4035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="4025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="4013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="4011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="4006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="4001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="4000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7245-false-d676400e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="3952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="3951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.2 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.3 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.5 is mandatory [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7253-false-d680617e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="3777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="3776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='CNE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='CNE'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '77386006' codeSystem '2.16.840.1.113883.6.96' displayName='Pregnant (finding)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de elementwaarde MOET een zijn van 'code '77386006' codeSystem '2.16.840.1.113883.6.96' displayName='Pregnant (finding)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7262-false-d684846e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="3602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="3601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '11996-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Pregnancies' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de elementwaarde MOET een zijn van 'code '11996-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Pregnancies' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7270-false-d689075e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="3427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="3426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '11977-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Parity' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de elementwaarde MOET een zijn van 'code '11977-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Parity' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7278-false-d693304e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="3252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="3251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '11778-8' codeSystem '2.16.840.1.113883.6.1' displayName='Delivery date Estimated' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de elementwaarde MOET een zijn van 'code '11778-8' codeSystem '2.16.840.1.113883.6.1' displayName='Delivery date Estimated' codeSystemName='LN''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="3234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="3233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7286-false-d697605e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="3073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="3072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.6 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='NM'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de element content van hl7v2:OBX.2 MOET ''NM'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='d')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='d')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code 'd''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='d')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='d')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de elementwaarde MOET een zijn van 'code 'd''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="2996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="2994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="2993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="2991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="2989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="2983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="2981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="2971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="2959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="2957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="2952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="2947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="2946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="2933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="2920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="2918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="2917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="2916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="2914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="2913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="2912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="2910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="2908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="2907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="2906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="2905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="2903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="2901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="2900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7294-false-d701837e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="2898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="2897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="2896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="2895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="2893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="2891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="2890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="2889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="2887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="2886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="2885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="2883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="2882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="2881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="2879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="2878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="2877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="2875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="2874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="2873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="2871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="2870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="2869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="2868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="2866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="2864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="2862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="2861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="2859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="2858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="2856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="2855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="2853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="2851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="2850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="2849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="2847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="2846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="2845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="2843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="2841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="2840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="2833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="2832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="2831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="2830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="2829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="2828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="2827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="2821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="2819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="2818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="2816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="2814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="2808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="2806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="2796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="2784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="2782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="2777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="2772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="2771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="2758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="2745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="2743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="2742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="2741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="2739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="2738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="2737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="2735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="2733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="2732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="2731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="2730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="2728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="2726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="2725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7302-false-d706054e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="2723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="2722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="2721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="2720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="2718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '418799008' codeSystem '2.16.840.1.113883.6.96' displayName='Finding reported by subject or history provider (finding)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de elementwaarde MOET een zijn van 'code '418799008' codeSystem '2.16.840.1.113883.6.96' displayName='Finding reported by subject or history provider (finding)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="2716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="2715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="2714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="2712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="2711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="2710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="2708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="2707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="2706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="2704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="2703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="2702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="2700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="2699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="2698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="2696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="2695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="2694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="2693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="2691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="2689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="2687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="2686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="2684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="2683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="2681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="2680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="2678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="2676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="2675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="2674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="2672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="2671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="2670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="2668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="2666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="2665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="2658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="2657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="2656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="2655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="2654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="2653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="2652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="2646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="2644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="2643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="2641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="2639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="2633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="2631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="2621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="2609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="2607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="2602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="2597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="2596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="2583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="2570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="2568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="2567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="2566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="2564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="2563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="2562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="2560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="2558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="2557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="2556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="2555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="2553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="2551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="2550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7311-false-d710283e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="2548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="2547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="2546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="2545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="2543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="2541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="2540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="2539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="2537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="2536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="2535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="2533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="2532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="2530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="2529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="2527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="2525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="2524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="2523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="2521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="2520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="2519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="2517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="2516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="2515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="2514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="2512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="2510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="2508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="2507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="2505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="2504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="2502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="2501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="2499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="2497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="2496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="2495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="2493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="2492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="2491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="2489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="2487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="2486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="2479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="2478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="2477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="2476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="2475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="2474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="2473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="2467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="2465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="2464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="2462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="2460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="2454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="2452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="2442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="2430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="2428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="2423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="2418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="2417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="2404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="2391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="2389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="2388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="2387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="2385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="2384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="2383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="2381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="2379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="2378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="2377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="2376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="2374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="2372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="2371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7319-false-d714569e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="2369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="2368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="2367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="2366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='TS'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de element content van hl7v2:OBX.2 MOET ''TS'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="2364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '71388002' codeSystem '2.16.840.1.113883.6.96' displayName='Verrichting (verrichting)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de elementwaarde MOET een zijn van 'code '71388002' codeSystem '2.16.840.1.113883.6.96' displayName='Verrichting (verrichting)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="2362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="2361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="2360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="2358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="2357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="2356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="2354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="2353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="2351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="2350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="2348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="2346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="2345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="2344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="2342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="2341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="2340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="2338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="2337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="2336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="2335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="2333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="2331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="2329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="2328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="2326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="2325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="2323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="2322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="2320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="2318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="2317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="2316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="2314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="2313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="2312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="2310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="2308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="2307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="2300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="2299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="2298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="2297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="2296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="2295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="2294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="2288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="2286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="2285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="2283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="2281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="2275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="2273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="2263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="2251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="2249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="2244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="2239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="2238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="2225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="2212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="2210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="2209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="2208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="2206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="2205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="2204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="2202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="2200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="2199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="2198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="2197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="2195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="2193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="2192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7327-false-d718870e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="2190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="2189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="2188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="2187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="2185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '313150002' codeSystem '2.16.840.1.113883.6.96' displayName='Synthetic surgical material (substance)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de elementwaarde MOET een zijn van 'code '313150002' codeSystem '2.16.840.1.113883.6.96' displayName='Synthetic surgical material (substance)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="2183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="2182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="2181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="2179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="2178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="2177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="2175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="2174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="2173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="2171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="2170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="2169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="2167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="2166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="2165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="2163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="2162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="2161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="2160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="2158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="2156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="2154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="2153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="2151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="2150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="2148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="2147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="2145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="2143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="2142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="2141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="2139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="2138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="2137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="2135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="2133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="2132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="2125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="2124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="2123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="2122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="2121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="2120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="2119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="2113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="2111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="2110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="2108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="2106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="2100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="2098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="2088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="2076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="2074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="2069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="2064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="2063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="2050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="2037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="2035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="2034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="2033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="2031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="2030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="2029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="2027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="2025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="2024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="2023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="2022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="2020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="2018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="2017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7335-false-d723088e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="2015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="2014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="2013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="2012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="2010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="2008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="2007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="2006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="2004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="2003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="2002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="2000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7343-false-d727294e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="1840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:NTE komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="1839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE"
                 priority="1665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '96' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Set ID - NTE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '97' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Table MOET 'HL70105' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Source of Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '98' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'FT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '1318' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Table MOET 'HL70364' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Comment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7353-false-d731956e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="1647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="1646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.2 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.5)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.5 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()='ST'">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de element content van hl7v2:OBX.2 MOET ''ST'' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de elementwaarde MOET een zijn van 'code '184104002' codeSystem '2.16.840.1.113883.6.96' displayName='Patient occupation (observable entity)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de elementwaarde MOET een zijn van 'code '184104002' codeSystem '2.16.840.1.113883.6.96' displayName='Patient occupation (observable entity)' codeSystemName='SNM''.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7362-false-d736182e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="1472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="1471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e7370-false-d740382e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="1297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OUL_R22_Lab2Lab): element hl7v2:TCD komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="1296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:OBX.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('569') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '569' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - OBX') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Set ID - OBX' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('570') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '570' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70125') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70125' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Value Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Value Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('571') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '571' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('572') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '572' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Sub-ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Sub-ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('573') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '573' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('varies') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'varies' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Value') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Value' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('574') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '574' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Units') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Units' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('575') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '575' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('References Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'References Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1269"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('576') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '576' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70078') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70078' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Abnormal Flags') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Abnormal Flags' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('577') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '577' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Probability') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Probability' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('578') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '578' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70080') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70080' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('579') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '579' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70085') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70085' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Result Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Result Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('580') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '580' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('581') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '581' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('User Defined Access Checks') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'User Defined Access Checks' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('582') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '582' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of the Observation' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('583') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '583' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Producer''s ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Producer''s ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.10)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.11)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.12)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.13)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.14)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.15)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.16)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.17)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.18)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.19)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.20)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.21)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.22)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:XCN.23)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('584') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '584' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('XCN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Responsible Observer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Responsible Observer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('ID Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:FN.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'FN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Family Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname Prefix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Own Surname') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Given Name') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70360') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70297') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source Table') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Authority') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70200') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Check Digit') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70061') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Check Digit Scheme') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70203') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier Type Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:HD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('HD') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'HD' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Facility') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70300') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70465') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Representation Code') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70448') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Context') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DR.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DR') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'DR' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Validity Range') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range Start Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Range End Date/Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70444') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name Assembly Order') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Effective Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Expiration Date') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Professional Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CWE.9)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CWE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Original Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('936') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '936' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Observation Method') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Method' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1479') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1479' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TS.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1480') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1480' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('TS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('DTM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'DTM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Time') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Time' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70529') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Degree of Precision') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD"
                 priority="1121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.7)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:TCD.8)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1"
                 priority="1120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('238') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '238' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal Service Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Universal Service Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="1118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="1117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="1116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="1114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="1113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="1112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2"
                 priority="1110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1420') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1420') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1420' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'SN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Auto-Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Auto-Dilution Factor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="1108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="1107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="1106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="1105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3"
                 priority="1104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1421') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1421') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1421' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'SN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Rerun Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Rerun Dilution Factor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="1102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="1101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="1100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="1099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4"
                 priority="1098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1422') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1422') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1422' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'SN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Pre-Dilution Factor') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Pre-Dilution Factor' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="1096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="1095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="1094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="1093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5"
                 priority="1092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SN.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1413') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1413') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1413' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SN') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'SN' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="1090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comparator') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="1089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num1') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="1088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Separator/Suffix') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="1087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('NM') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @Type MOET 'NM' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Num2') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.6"
                 priority="1086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1416') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1416') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1416' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Automatic Repeat Allowed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Automatic Repeat Allowed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.7"
                 priority="1084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1424') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1424') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1424' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70136') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Reflex Allowed') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Reflex Allowed' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8"
                 priority="1082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1425') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1425') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Item MOET '1425' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70389') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @Table MOET 'HL70389' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Analyte Repeat Status') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(TCD_segment): de waarde van @LongName MOET 'Analyte Repeat Status' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="1080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="1079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="1078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="1076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="1075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="1074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID"
                 priority="1072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:SID.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): element hl7v2:SID.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1"
                 priority="1071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1426') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1426') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Item MOET '1426' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Application / Method Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Application / Method Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @LongName MOET 'Application / Method Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.1"
                 priority="1069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.2"
                 priority="1068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.3"
                 priority="1067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.4"
                 priority="1065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.5"
                 priority="1064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.6"
                 priority="1063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.2"
                 priority="1061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1129') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1129') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Item MOET '1129' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Lot Number') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Substance Lot Number') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @LongName MOET 'Substance Lot Number' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.3"
                 priority="1060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1428') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1428') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Item MOET '1428' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Substance Container Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @LongName MOET 'Substance Container Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4"
                 priority="1059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1429') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1429') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Item MOET '1429' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70385') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70385') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @Table MOET 'HL70385' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Manufacturer Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Substance Manufacturer Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(SID_segment): de waarde van @LongName MOET 'Substance Manufacturer Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.1"
                 priority="1057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.2"
                 priority="1056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.3"
                 priority="1055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.4"
                 priority="1053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.5"
                 priority="1052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.6"
                 priority="1051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE"
                 priority="1049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.3)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.3 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:NTE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('96') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '96' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('SI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'SI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Set ID - NTE') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('97') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '97' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70105') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Source of Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('98') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '98' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('FT') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'FT' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(FT_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@V">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(escapeType_datatype): attribute @V MOET aanwezig zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1318') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Item MOET '1318' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70364') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Comment Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI"
                 priority="1031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1)&gt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.1)&gt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.1 is required [min 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CTI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): element hl7v2:CTI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1"
                 priority="1030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:EI.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1011') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1011') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @Item MOET '1011' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('EI') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @Type MOET 'EI' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sponsor Study ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Sponsor Study ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @LongName MOET 'Sponsor Study ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.1"
                 priority="1028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Entity Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.2"
                 priority="1027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('IS') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'IS' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70363') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Namespace ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.3"
                 priority="1026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.4"
                 priority="1025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70301') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Universal ID Type') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2"
                 priority="1023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1022') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1022') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @Item MOET '1022' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Study Phase Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Study Phase Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @LongName MOET 'Study Phase Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.1"
                 priority="1021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.2"
                 priority="1020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.3"
                 priority="1019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.4"
                 priority="1017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.5"
                 priority="1016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.6"
                 priority="1015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3"
                 priority="1013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.3)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.4)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.5)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:CE.6)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1055') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1055') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @Item MOET '1055' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('CE') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @Type MOET 'CE' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Study Scheduled Time Point') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Study Scheduled Time Point') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CTI_segment): de waarde van @LongName MOET 'Study Scheduled Time Point' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.1"
                 priority="1011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.2"
                 priority="1010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.3"
                 priority="1009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.4"
                 priority="1007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Identifier') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.5"
                 priority="1006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Alternate Text') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.6"
                 priority="1005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70396') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC" priority="1003" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC.1)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DSC.1)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): element hl7v2:DSC.1 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC.2)&lt;=1"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="count(hl7v2:DSC.2)&lt;=1">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): element hl7v2:DSC.2 komt te vaak voor [max 1x].</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/hl7v2:DSC.1"
                 priority="1002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('14') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('14') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @Item MOET '14' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ST') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @Type MOET 'ST' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Continuation Pointer') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @LongName MOET 'Continuation Pointer' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/hl7v2:DSC.2"
                 priority="1001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="not(@MaxLength)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(ID_datatype): attribute @MaxLength MAG NIET voorkomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1354') or not(@Item)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Item)=('1354') or not(@Item)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @Item MOET '1354' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Type)=('ID') or not(@Type)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @Type MOET 'ID' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70398') or not(@Table)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@Table)=('HL70398') or not(@Table)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @Table MOET 'HL70398' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Style') or not(@LongName)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="string(@LongName)=('Continuation Style') or not(@LongName)">
               <xsl:attribute name="see">http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html</xsl:attribute>
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>(DSC_segment): de waarde van @LongName MOET 'Continuation Style' zijn.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.32-2016-05-31T000000-closedLab2Lab Resultaatbericht (OUL^R22)-->
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Lab2Lab Resultaatbericht (OUL^R22)</svrl:text>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
</xsl:stylesheet>
